package java.util;

import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.Serializable;

public class Hashtable extends Dictionary implements Cloneable, Serializable {
   private transient HashtableEntry[] table;
   private transient int count;
   private int threshold;
   private float loadFactor;
   private static final long serialVersionUID = 1421746759512286392L;

   public Hashtable(int var1, float var2) {
      if (var1 > 0 && !((double)var2 <= (double)0.0F)) {
         this.loadFactor = var2;
         this.table = new HashtableEntry[var1];
         this.threshold = (int)((float)var1 * var2);
      } else {
         throw new IllegalArgumentException();
      }
   }

   public Hashtable(int var1) {
      this(var1, 0.75F);
   }

   public Hashtable() {
      this(101, 0.75F);
   }

   public int size() {
      return this.count;
   }

   public boolean isEmpty() {
      return this.count == 0;
   }

   public synchronized Enumeration keys() {
      return new HashtableEnumerator(this.table, true);
   }

   public synchronized Enumeration elements() {
      return new HashtableEnumerator(this.table, false);
   }

   public synchronized boolean contains(Object var1) {
      if (var1 == null) {
         throw new NullPointerException();
      } else {
         HashtableEntry[] var2 = this.table;
         int var3 = var2.length;

         while(var3-- > 0) {
            for(HashtableEntry var4 = var2[var3]; var4 != null; var4 = var4.next) {
               if (var4.value.equals(var1)) {
                  return true;
               }
            }
         }

         return false;
      }
   }

   public synchronized boolean containsKey(Object var1) {
      HashtableEntry[] var2 = this.table;
      int var3 = var1.hashCode();
      int var4 = (var3 & Integer.MAX_VALUE) % var2.length;

      for(HashtableEntry var5 = var2[var4]; var5 != null; var5 = var5.next) {
         if (var5.hash == var3 && var5.key.equals(var1)) {
            return true;
         }
      }

      return false;
   }

   public synchronized Object get(Object var1) {
      HashtableEntry[] var2 = this.table;
      int var3 = var1.hashCode();
      int var4 = (var3 & Integer.MAX_VALUE) % var2.length;

      for(HashtableEntry var5 = var2[var4]; var5 != null; var5 = var5.next) {
         if (var5.hash == var3 && var5.key.equals(var1)) {
            return var5.value;
         }
      }

      return null;
   }

   protected void rehash() {
      int var1 = this.table.length;
      HashtableEntry[] var2 = this.table;
      int var3 = var1 * 2 + 1;
      HashtableEntry[] var4 = new HashtableEntry[var3];
      this.threshold = (int)((float)var3 * this.loadFactor);
      this.table = var4;
      int var5 = var1;

      HashtableEntry var7;
      int var8;
      while(var5-- > 0) {
         for(HashtableEntry var6 = var2[var5]; var6 != null; var4[var8] = var7) {
            var7 = var6;
            var6 = var6.next;
            var8 = (var7.hash & Integer.MAX_VALUE) % var3;
            var7.next = var4[var8];
         }
      }

   }

   public synchronized Object put(Object var1, Object var2) {
      if (var2 == null) {
         throw new NullPointerException();
      } else {
         HashtableEntry[] var3 = this.table;
         int var4 = var1.hashCode();
         int var5 = (var4 & Integer.MAX_VALUE) % var3.length;

         for(HashtableEntry var6 = var3[var5]; var6 != null; var6 = var6.next) {
            if (var6.hash == var4 && var6.key.equals(var1)) {
               Object var7 = var6.value;
               var6.value = var2;
               return var7;
            }
         }

         if (this.count >= this.threshold) {
            this.rehash();
            return this.put(var1, var2);
         } else {
            HashtableEntry var8 = new HashtableEntry();
            var8.hash = var4;
            var8.key = var1;
            var8.value = var2;
            var8.next = var3[var5];
            var3[var5] = var8;
            ++this.count;
            return null;
         }
      }
   }

   public synchronized Object remove(Object var1) {
      HashtableEntry[] var2 = this.table;
      int var3 = var1.hashCode();
      int var4 = (var3 & Integer.MAX_VALUE) % var2.length;
      HashtableEntry var5 = var2[var4];

      for(HashtableEntry var6 = null; var5 != null; var5 = var5.next) {
         if (var5.hash == var3 && var5.key.equals(var1)) {
            if (var6 != null) {
               var6.next = var5.next;
            } else {
               var2[var4] = var5.next;
            }

            --this.count;
            return var5.value;
         }

         var6 = var5;
      }

      return null;
   }

   public synchronized void clear() {
      HashtableEntry[] var1 = this.table;
      int var2 = var1.length;

      while(true) {
         --var2;
         if (var2 < 0) {
            this.count = 0;
            return;
         }

         var1[var2] = null;
      }
   }

   public synchronized Object clone() {
      try {
         Hashtable var1 = (Hashtable)super.clone();
         var1.table = new HashtableEntry[this.table.length];

         for(int var2 = this.table.length; var2-- > 0; var1.table[var2] = this.table[var2] != null ? (HashtableEntry)this.table[var2].clone() : null) {
         }

         return var1;
      } catch (CloneNotSupportedException var3) {
         throw new InternalError();
      }
   }

   public synchronized String toString() {
      int var1 = this.size() - 1;
      StringBuffer var2 = new StringBuffer();
      Enumeration var3 = this.keys();
      Enumeration var4 = this.elements();
      var2.append("{");

      for(int var5 = 0; var5 <= var1; ++var5) {
         String var6 = var3.nextElement().toString();
         String var7 = var4.nextElement().toString();
         var2.append(var6 + "=" + var7);
         if (var5 < var1) {
            var2.append(", ");
         }
      }

      var2.append("}");
      return var2.toString();
   }

   private synchronized void writeObject(ObjectOutputStream var1) throws IOException {
      var1.defaultWriteObject();
      var1.writeInt(this.table.length);
      var1.writeInt(this.count);

      for(int var2 = this.table.length - 1; var2 >= 0; --var2) {
         for(HashtableEntry var3 = this.table[var2]; var3 != null; var3 = var3.next) {
            var1.writeObject(var3.key);
            var1.writeObject(var3.value);
         }
      }

   }

   private synchronized void readObject(ObjectInputStream var1) throws IOException, ClassNotFoundException {
      var1.defaultReadObject();
      int var2 = var1.readInt();
      int var3 = var1.readInt();
      int var4 = (int)((float)var3 * this.loadFactor) + var3 / 20 + 3;
      if (var4 > var3 && (var4 & 1) == 0) {
         --var4;
      }

      if (var2 > 0 && var4 > var2) {
         var4 = var2;
      }

      this.table = new HashtableEntry[var4];

      for(this.count = 0; var3 > 0; --var3) {
         Object var5 = var1.readObject();
         Object var6 = var1.readObject();
         this.put(var5, var6);
      }

   }
}
