package java.util.zip;

import java.io.EOFException;
import java.io.FilterInputStream;
import java.io.IOException;
import java.io.InputStream;

public class InflaterInputStream extends FilterInputStream {
   protected Inflater inf;
   protected byte[] buf;
   protected int len;

   public InflaterInputStream(InputStream var1, Inflater var2, int var3) {
      super(var1);
      this.inf = var2;
      this.buf = new byte[var3];
   }

   public InflaterInputStream(InputStream var1, Inflater var2) {
      this(var1, var2, 512);
   }

   public InflaterInputStream(InputStream var1) {
      this(var1, new Inflater());
   }

   public int read() throws IOException {
      byte[] var1 = new byte[1];
      return this.read(var1, 0, 1) == -1 ? -1 : var1[0] & 255;
   }

   public int read(byte[] var1, int var2, int var3) throws IOException {
      if (var3 <= 0) {
         return 0;
      } else {
         try {
            int var4;
            while((var4 = this.inf.inflate(var1, var2, var3)) == 0) {
               if (this.inf.finished() || this.inf.needsDictionary()) {
                  return -1;
               }

               if (this.inf.needsInput()) {
                  this.fill();
               }
            }

            return var4;
         } catch (DataFormatException var6) {
            String var5 = ((Throwable)var6).getMessage();
            throw new ZipException(var5 != null ? var5 : "Invalid ZLIB data format");
         }
      }
   }

   public long skip(long var1) throws IOException {
      byte[] var3 = new byte[512];

      long var4;
      long var8;
      for(var4 = 0L; var4 < var1; var4 += var8) {
         var8 = var1 - var4;
         var8 = (long)this.read(var3, 0, var8 < (long)var3.length ? (int)var8 : var3.length);
         if (var8 == -1L) {
            break;
         }
      }

      return var4;
   }

   protected void fill() throws IOException {
      this.len = super.in.read(this.buf, 0, this.buf.length);
      if (this.len == -1) {
         throw new EOFException("Unexpected end of ZLIB input stream");
      } else {
         this.inf.setInput(this.buf, 0, this.len);
      }
   }
}
